@@ -1,8 +1,8 @@
 package Perinci::Sub::ValidateArgs;
 
 # NOIFBUILT
-our $DATE = '2016-05-23'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2016-05-24'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use strict 'subs', 'vars';
 use warnings;
@@ -78,7 +78,7 @@ Perinci::Sub::ValidateArgs - Validate function arguments using schemas in Rinci
 
 =head1 VERSION
 
-This document describes version 0.004 of Perinci::Sub::ValidateArgs (from Perl distribution Perinci-Sub-ValidateArgs), released on 2016-05-23.
+This document describes version 0.005 of Perinci::Sub::ValidateArgs (from Perl distribution Perinci-Sub-ValidateArgs), released on 2016-05-24.
 
 =head1 SYNOPSIS
 
@@ -121,16 +121,19 @@ An alternative to this module is L<Dist::Zilla::Plugin::Rinci::Validate>
 with generated validator code.
 
 Using DZP:RV is faster (see/run the benchmark in
-L<Bencher::Scenario::PerinciSubValidateArgs::Overhead>), but you need to build
-the distribution first and use the built version. Using PSV is slower (up to
-several times, plus there is a startup overhead of compiling the Data::Sah
-validators the first time the function is called), but is more flexible because
-you don't have to build the distribution first.
+L<Bencher::Scenario::PerinciSubValidateArgs::Overhead>) and avoid dependencies
+on Data::Sah itself, but you need to build your code as a proper distribution
+first and use the built version. Using PSV is slower (up to several times, plus
+there is a startup overhead of compiling the Data::Sah validators the first time
+the function is called) and makes you dependent on Data::Sah during runtime, but
+is more flexible because you don't have to build your code as a distribution
+first.
 
 A strategy can be made using L<Dist::Zilla::Plugin::IfBuilt>. You mark the PSV
 parts with C<#IFUNBUILT> and C<#END IFUNBUILT> directives so the PSV part is
 only used in the unbuilt version, while the built/production version uses the
-faster DZP:RV.
+faster DZP:RV. But this still requires you to organize your code as a proper
+distribution.
 
 BTW, yet another alternative is to use L<Perinci::CmdLine::Lite> or
 L<Perinci::CmdLine::Inline>. These two frameworks can generate the argument
